@@ -1,6 +1,6 @@
 #' Calculation of expression \eqn{x\cdot \log y}
 #' 
-#' Internal, auxillary functions
+#' Internal, auxiliary functions
 #'
 #' @param x is a numeric vector
 #' @param y is a numeric vector (the same length of x)
@@ -17,9 +17,9 @@ aux_x_log_y<-function(x,y){
   ids=is.infinite(out)
   out[ids]=x[ids]*log(y[ids])
 
-  if (length(x)>100000){
-  	temp=e1071::moment(x)
-  	temp_str=Hmisc::capitalize("large")
+  if (is.list(x)){
+  	Hmisc::capitalize("Only for consistency for CRAN submission -- to bypass a bug within nnet package")
+  	e1071::moment(x)
   }
 
   out
